/*REPLICATES TABLES IN FIGURES IN PAPER*/

clear
set more off
set matsize 4000

****************
*DIRECTORY*
****************
	
    global replication  C:\Users\cecilia.machado\Dropbox\jmp_revision\jae_revision\replication\  /*directory where data fileshould be placed*/
	
**********************
/*TABLE 2*/
**********************

cap program drop table2
program define table2	
	
	clear
    insheet using ${replication}nlsy79.csv	
	
	local ae count c_childunder6 e11v3_ftfy e11v2_ftfy e11v1_ftfy 
	local vars iq_afqtrank iq_pca4rank iq_pca10rank managers  hiprof cumul_numhours44 pct_ftfy 
	global x: word count `vars'
	matrix D=J(${x}+1,4,0)

	local j=0
	local weight weight_panel_2012
	
    capture erase "${replication}table2.tex"

	foreach type in `ae' {
	
	gen type=1
	replace type=`type' if female==1
	
	if "`j'"=="0" local cond replace
	if "`j'"!="0" local cond append
	
	tabstat `vars' [aw=`weight'] if type==1 & year==1979, stats(mean) by(female) save
	matrix A`type'=r(Stat1)', r(Stat2)'
	tabstat count [aw=`weight'] if type==1 & year==1979, stats(count) by(female) save
	matrix C=r(Stat1)',r(Stat2)'
	matrix A`type'=A`type'\C
	
	local k=1
	foreach v in `vars' {
	regress `v' female [aw=`weight'] if type==1 & year==1979
	matrix D[`k',1]=_b[female]
	matrix D[`k',2]=_se[female]
	matrix D[`k',3]=_b[female]/_se[female]
	local t= _b[female]/_se[female]
	matrix D[`k',4]=2*ttail(e(df_r),abs(`t'))
	local k=`k'+1
	}
	
	matrix A`type'=A`type',D
	matrix colnames A`type' = "MALE" "FEMALE" "Diff" "SE" "t-stat" "p-value" 
	matrix B`type'=A`type''
	esttab matrix(B`type',fmt(3)) using ${replication}table2.tex, `cond' //.tex works as well

	local j=`j'+1
	
	drop type
	}

	
end

**********************
/*TABLE 3*/
**********************

capture program drop table3
program define table3

clear
insheet using ${replication}cps.csv	

local condition1 "if female==1"
local condition2 "if female==1 & year>=1976 & year<=1980"
local condition3 "if female==1 & year>=2001 & year<=2005"
local condition4 "if female==0"
local condition5 "if female==0 & year>=1976 & year<=1980"
local condition6 "if female==0 & year>=2001 & year<=2005"

local vars eduhsless edu12 edu1315 educollegeplus child6 child6_0 child6_1 child6_2 child6_3p ///
employed w_employed employedz0 employedz1 ft w_ft ftz0 ftz1 married widowed divorced separated nevermarr edushsless edus12 edus1315 eduscollegeplus lnw_spouse2 

forvalues i=1/6 {
tabstat `vars' [aw=wgt] `condition`i'' , stats(mean) save
matrix A`i'=r(StatTotal)'
count `condition`i''
matrix A`i'= A`i' \ r(N)
}
matrix B= A1, A2, A3, A4, A5, A6

matrix rownames B = "less than hs" "hs grad" "some college" "college or more" ///
"numb child leq 6" "no child leq 6" "1 child leq 6" "2 children leq 6" "3+ children leq 6" "employed" "wage" "employed no child6" "employed child6 present" ///
"full time" "wage ft" "ft no child6"  "ft child6 present" "married" "widowed" "divorced" "separated" "never married" ///
"sp less than hs" "sp hs grad" "sp some college" "sp college or more" ///
"sp lnwage""N" 
matrix colnames B = "F76-05" "F76-80" "F01-05" "M76-05" "M76-80" "M01-05"

capture erase "${replication}table3.tex"
estout matrix(B, fmt(3)) using "${replication}table3.tex" , style(tex) replace


end // program table3


**********************************************
/*TABLE 4 (combination of tables 4a and 4b)*/
**********************************************

capture program drop table4
program define table4

clear
insheet using ${replication}cps.csv	

local particip employed ft 

local condition1 "if year>=1976 & year<=1980 & (eduhsless==1)"
local condition2 "if year>=1976 & year<=1980 & (edu12==1)"
local condition3 "if year>=1976 & year<=1980 & (edu1315==1)"
local condition4 "if year>=1976 & year<=1980 & (educollegeplus==1)"
local condition5 "if year>=2001 & year<=2005 & (eduhsless==1)"
local condition6 "if year>=2001 & year<=2005 & (edu12==1)"
local condition7 "if year>=2001 & year<=2005 & (edu1315==1)"
local condition8 "if year>=2001 & year<=2005 & (educollegeplus==1)"

forvalues j=1/8 {
foreach participation in `particip' {

reg w_`participation' female [pw=wgt] `condition`j'' & `participation'==1
matrix b=e(b)
matrix V=e(V)
scalar mgap=b[1,1]
scalar mgapse=sqrt(V[1,1])

reg w_`participation' female fiv [pw=wgt] `condition`j'' & `participation'==1
estimates store r`participation'_`j'
lincom female+fiv
scalar gap=r(estimate)
scalar gse=r(se)
estimates restore r`participation'_`j'
estadd scalar gap=gap
estadd scalar gse=gse
estadd scalar mgap=mgap
estadd scalar mgapse=mgapse
estimates store r`participation'_`j' 

}
}

capture erase "${replication}table4a.tex"
forvalues j=1/4 {
local h=`j'
local i=`j'+4
estout remployed_`h' remployed_`i' rft_`h' rft_`i' ///
	using "${replication}table4a.tex", cells(b(star fmt(3)) se(fmt(3) par)) stats(r2 N gap gse mgap mgapse, fmt(3 0 3 3 3) labels("R^2" "Obs" "Local Gap" "se" "Measured Gap" "se")) ///
	numbers starlevels(* 0.10 ** 0.05 *** 0.01) append style(tex) 
}


keep if (year>=1976 & year<=1980)| (year>=2001 & year<=2005)

gen dy00=(year>=2001 & year<=2005)
gen dy00_female= dy00*female
gen dy00_fiv= dy00*fiv

local condition1 "if (eduhsless==1)"
local condition2 "if (edu12==1)"
local condition3 "if (edu1315==1)"
local condition4 "if (educollegeplus==1)"

reg w_employed female [pw=wgt] if eduhsless==1 & employed==1 & dy00==0
reg w_employed female [pw=wgt] if eduhsless==1 & employed==1 & dy00==1
reg w_employed female dy00 dy00_female [pw=wgt] if eduhsless==1 & employed==1

forvalues j=1/4 {
foreach participation in `particip' {
reg w_`participation' dy00_female female dy00  [pw=wgt] `condition`j'' & `participation'==1
matrix b=e(b)
matrix V=e(V)
scalar o`participation'=b[1,1]
scalar ose`participation'=sqrt(V[1,1])
 
reg w_`participation' dy00_fiv dy00_female dy00 female fiv  [pw=wgt] `condition`j'' & `participation'==1
lincom dy00_female+dy00_fiv 
scalar l`participation'=r(estimate)
scalar lse`participation'=r(se)

matrix A`participation'`j'=l`participation'\lse`participation'\o`participation'\ose`participation'
}
}

matrix A=Aemployed1,Aft1 \ Aemployed2,Aft2 \Aemployed3,Aft3 \Aemployed4,Aft4

matrix rownames A = "HS less local" "" "HS less obs" "" "HS local" "" "HS Obs" "" "Some College local" ""  "Some College obs" "" "College More local" "" "College More obs" "" 
matrix colnames A = "Any" "FT"


capture erase "${replication}table4b.tex"
estout matrix(A, fmt(3)) using "${replication}table4b.tex" , style(tex) replace

end // program table4


**************************
/*TABLE 5 */
**************************

capture program drop table5
program define table5

**PANELS A AND B

clear
insheet using ${replication}cps.csv	

preserve

tab group_edu, gen(dedu)

local iv anychild6
local particip employed ft 

gen d70=(year>=1976&year<=1980)
gen d00=(year>=2001&year<=2005)
replace d70=. if year>=1981 & year<=2000
replace d00=. if year>=1981 & year<=2000
foreach y in 70 00 {
forvalues i=1/4 {
gen d`y'_`i'=d`y'*dedu`i'
gen d`y'df_`i'=d`y'*female*dedu`i'
gen d`y'dfdz_`i'=d`y'*female*`iv'*dedu`i'

local g`y'e`i' "(d`y'df_`i'+d`y'dfdz_`i')"
local gm`y'e`i' "(d`y'df_`i')"
}
}

local condition1 "if year>=1976 & year<=1980 & female==1"
local condition2 "if year>=2001 & year<=2005 & female==1"
local condition3 "if year>=1976 & year<=1980 & female==0"
local condition4 "if year>=2001 & year<=2005 & female==0"
forvalues i=1/4 {
tabstat dedu* [aw=wgt]  `condition`i'' , stats(mean) save
matrix A`i'=r(StatTotal)'
tabstat dedu* [aw=wgt]  `condition`i'' & employed==1 & anychild6==1, stats(mean) save
matrix H`i'=r(StatTotal)'
tabstat dedu* [aw=wgt]  `condition`i'' & ft==1 & anychild6==1, stats(mean) save
matrix I`i'=r(StatTotal)'
}
matrix B= A1, A2, A3, A4, H1, H2, I1, I2, H3, H4, I3, I4

forvalues i=1/4 {
forvalues k=1/4 {
scalar sca_`i'_`k' = B[`k',`i']
}
}

foreach participation in `particip' {
reg w_`participation' d70_* d70df_* d70dfdz_* ///
	                  d00_* d00df_* d00dfdz_* [pw=wgt] if `participation'==1, noc

forvalues i=1/4 {

local comb70 sca_`i'_1*`g70e1'
forvalues k=2/4 {
local comb70 `comb70'+sca_`i'_`k'*`g70e`k''
}
lincom `comb70'
matrix C`i'=(r(estimate)\r(se))

local comb00 sca_`i'_1*`g00e1'
forvalues k=2/4 {
local comb00 `comb00'+sca_`i'_`k'*`g00e`k''
}
lincom `comb00'
matrix D`i'=(r(estimate)\r(se))

forvalues j=1/4 {
local comb00b -sca_`j'_1*`g00e1'
forvalues k=2/4 {
local comb00b `comb00b'-sca_`j'_`k'*`g00e`k''
}
lincom `comb70' `comb00b'
matrix E`i'`j'=(r(estimate)\r(se))
}

}

if "`participation'"=="employed" matrix F1`participation'=(C1,D2,E12\C1,D1,E11\C2,D2,E22\C3,D4,E34)
if "`participation'"=="ft" matrix F1`participation'=(C1,D2,E12\C1,D1,E11\C2,D2,E22\C3,D4,E34)

reg w_`participation' d70_* d70df_*  ///
	                  d00_* d00df_* [pw=wgt] if `participation'==1, noc
forvalues i=1/4 {

local comb70 sca_`i'_1*`gm70e1'
forvalues k=2/4 {
local comb70 `comb70'+sca_`i'_`k'*`gm70e`k''
}
lincom `comb70'
matrix C`i'=(r(estimate)\r(se))

local comb00 sca_`i'_1*`gm00e1'
forvalues k=2/4 {
local comb00 `comb00'+sca_`i'_`k'*`gm00e`k''
}
lincom `comb00'
matrix D`i'=(r(estimate)\r(se))

forvalues j=1/4 {
local comb00b -sca_`j'_1*`gm00e1'
forvalues k=2/4 {
local comb00b `comb00b'-sca_`j'_`k'*`gm00e`k''
}
lincom `comb70' `comb00b'
matrix E`i'`j'=(r(estimate)\r(se))
}

}

if "`participation'"=="employed" matrix F2`participation'=(C1,D2,E12\C1,D1,E11\C2,D2,E22\C3,D4,E34)
if "`participation'"=="ft" matrix F2`participation'=(C1,D2,E12\C1,D1,E11\C2,D2,E22\C3,D4,E34)
}

matrix GAB=F1employed,F2employed\F1ft,F2ft

matrix rownames GAB = "ANY Female Variable Weights" "se" "Female Fixed Weights 76-80" "se" "Female Fixed Weights 01-05" "se" "Male Variable Weights" "se" ///
"FT Female Variable Weights" "se" "Female Fixed Weights 76-80" "se" "Female Fixed Weights 01-05" "se" "Male Variable Weights" "se"
matrix colnames GAB = "L 76-80" "L 01-05" "L Diff" "M 76-80" "M 01-05" "M Diff"

restore

**PANELS C AND D

preserve

tab group_edumar, gen(dedumar)

local iv anychild6
local particip employed ft /*employedr ftr*/

gen d70=(year>=1976&year<=1980)
gen d00=(year>=2001&year<=2005)
replace d70=. if year>=1981 & year<=2000
replace d00=. if year>=1981 & year<=2000
foreach y in 70 00 {
forvalues i=1/12 {
gen d`y'_`i'=d`y'*dedumar`i'
gen d`y'df_`i'=d`y'*female*dedumar`i'
gen d`y'dfdz_`i'=d`y'*female*`iv'*dedumar`i'

local g`y'e`i' "(d`y'df_`i'+d`y'dfdz_`i')"
local gm`y'e`i' "(d`y'df_`i')"
}
}

local condition1 "if year>=1976 & year<=1980 & female==1"
local condition2 "if year>=2001 & year<=2005 & female==1"
local condition3 "if year>=1976 & year<=1980 & female==0"
local condition4 "if year>=2001 & year<=2005 & female==0"
forvalues i=1/4 {
tabstat dedumar* [aw=wgt]  `condition`i'' , stats(mean) save
matrix A`i'=r(StatTotal)'
tabstat dedumar* [aw=wgt]  `condition`i'' & employed==1 & anychild6==1, stats(mean) save
matrix H`i'=r(StatTotal)'
tabstat dedumar* [aw=wgt]  `condition`i'' & ft==1 & anychild6==1, stats(mean) save
matrix I`i'=r(StatTotal)'
}
matrix B= A1, A2, A3, A4, H1, H2, I1, I2, H3, H4, I3, I4


forvalues i=1/4 {
forvalues k=1/12 {
scalar sca_`i'_`k' = B[`k',`i']
}
}

foreach participation in `particip' {
reg w_`participation' d70_* d70df_* d70dfdz_* ///
	                  d00_* d00df_* d00dfdz_* [pw=wgt] if `participation'==1, noc

forvalues i=1/4 {

local comb70 sca_`i'_1*`g70e1'
forvalues k=2/12 {
local comb70 `comb70'+sca_`i'_`k'*`g70e`k''
}
lincom `comb70'
matrix C`i'=(r(estimate)\r(se))

local comb00 sca_`i'_1*`g00e1'
forvalues k=2/12 {
local comb00 `comb00'+sca_`i'_`k'*`g00e`k''
}
lincom `comb00'
matrix D`i'=(r(estimate)\r(se))

forvalues j=1/4 {
local comb00b -sca_`j'_1*`g00e1'
forvalues k=2/12 {
local comb00b `comb00b'-sca_`j'_`k'*`g00e`k''
}
lincom `comb70' `comb00b'
matrix E`i'`j'=(r(estimate)\r(se))
}

}

if "`participation'"=="employed" matrix F1`participation'=(C1,D2,E12\C1,D1,E11\C2,D2,E22\C3,D4,E34)
if "`participation'"=="ft" matrix F1`participation'=(C1,D2,E12\C1,D1,E11\C2,D2,E22\C3,D4,E34)

reg w_`participation' d70_* d70df_*  ///
	                  d00_* d00df_* [pw=wgt] if `participation'==1, noc
forvalues i=1/4 {

local comb70 sca_`i'_1*`gm70e1'
forvalues k=2/12 {
local comb70 `comb70'+sca_`i'_`k'*`gm70e`k''
}
lincom `comb70'
matrix C`i'=(r(estimate)\r(se))

local comb00 sca_`i'_1*`gm00e1'
forvalues k=2/12 {
local comb00 `comb00'+sca_`i'_`k'*`gm00e`k''
}
lincom `comb00'
matrix D`i'=(r(estimate)\r(se))

forvalues j=1/4 {
local comb00b -sca_`j'_1*`gm00e1'
forvalues k=2/12 {
local comb00b `comb00b'-sca_`j'_`k'*`gm00e`k''
}
lincom `comb70' `comb00b'
matrix E`i'`j'=(r(estimate)\r(se))
}

}

if "`participation'"=="employed" matrix F2`participation'=(C1,D2,E12\C1,D1,E11\C2,D2,E22\C3,D4,E34)
if "`participation'"=="ft" matrix F2`participation'=(C1,D2,E12\C1,D1,E11\C2,D2,E22\C3,D4,E34)
}

matrix GCD=F1employed,F2employed\F1ft,F2ft

matrix rownames GCD = "ANY Female Variable Weights" "se" "Female Fixed Weights 76-80" "se" "Female Fixed Weights 01-05" "se" "Male Variable Weights" "se" ///
"FT Female Variable Weights" "se" "Female Fixed Weights 76-80" "se" "Female Fixed Weights 01-05" "se" "Male Variable Weights" "se"
matrix colnames GCD = "L 76-80" "L 01-05" "L Diff" "M 76-80" "M 01-05" "M Diff"


capture erase "${replication}table5.tex"

matrix G= GAB \ GCD

estout matrix(G, fmt(3)) using "${replication}table5.tex" , style(tex) replace

restore


end // program table5


*****************************************
/*FIGURE 1 */
****************************************

capture program drop figure1
program define figure1

	clear
    insheet using ${replication}nlsy79.csv	
	
	keep if female==1
	keep if white==1
	keep if agegen>=25 & agegen<=44
	tab year, gen (dyear)
	tab agegen, gen (dage)
	drop dyear1 dage1

foreach weight in weight {

xi, noomit: reg ftfy i.deciles_iq_afqtrank lesshs hs somecollege collegeormore married dage* dyear* [pw=`weight'], noc
estimates store reg1`var'
matrix D1=_b[ _Ideciles_i_1]
forvalues j=2(1)10 {
matrix D1=D1,_b[ _Ideciles_i_`j']
} 

xi, noomit: reg ftfy i.deciles_iq_pca4rank lesshs hs somecollege collegeormore married dage* dyear* [pw=`weight'], noc
estimates store reg1`var'
matrix D2=_b[ _Ideciles_i_1]
forvalues j=2(1)10 {
matrix D2=D2,_b[ _Ideciles_i_`j']
} 

xi, noomit: reg ftfy i.deciles_iq_pca10rank lesshs hs somecollege collegeormore married dage* dyear* [pw=`weight'], noc
estimates store reg2`var'
matrix D3=_b[ _Ideciles_i_1]
forvalues j=2(1)10 {
matrix D3=D3,_b[ _Ideciles_i_`j']
} 

matrix D0= 1,2,3,4,5,6,7,8,9,10
matrix D=D0',D1',D2',D3'
preserve
clear
svmat D
twoway (connect D2 D1) (connect D3 D1) (connect D4 D1), /// 
legend(label(1 "AFQT") label(2 "ASVAB 4") label(3 "ASVAB 10") rows(1)) ///
ytitle("") xtitle(test score deciles) scheme(s2color) graphregion(fcolor(white)) xlabel(1(1)10) ylabel(.2(.1).7, labsize(small)) name(`var', replace)

graph save ${replication}figure1.gph, asis replace
graph export ${replication}figure1.eps, replace

restore
}
xi, noomit: reg ftfy i.deciles_iq_afqtrank lesshs hs somecollege collegeormore married dage* dyear* [pw=weight], noc
lincom  _Ideciles_i_6-_Ideciles_i_10

xi, noomit: reg ftfy i.deciles_iq_pca4rank lesshs hs somecollege collegeormore married dage* dyear* [pw=weight], noc
lincom  _Ideciles_i_6-_Ideciles_i_10

xi, noomit: reg ftfy i.deciles_iq_pca10rank lesshs hs somecollege collegeormore married dage* dyear* [pw=weight], noc
lincom  _Ideciles_i_6-_Ideciles_i_10

end



*****************************************
/*FIGURE 2 */
****************************************

capture program drop figure2
program define figure2

clear
insheet using ${replication}cps.csv	

local iv anychild6
local condition1 "if year>=1976 & year<=1980"
local condition2 "if year>=1981 & year<=1985"
local condition3 "if year>=1986 & year<=1990"
local condition4 "if year>=1991 & year<=1995"
local condition5 "if year>=1996 & year<=2000"
local condition6 "if year>=2001 & year<=2005"

foreach edu in eduhsless edu12 edu1315 educollegeplus {
gen df_`edu'=female*`edu'
gen dfdz_`edu'=female*`iv'*`edu'
}
local ge1 "(df_eduhsless+dfdz_eduhsless)"
local ge2 "(df_edu12+dfdz_edu12)"
local ge3 "(df_edu1315+dfdz_edu1315)"
local ge4 "(df_educollegeplus+dfdz_educollegeplus)"
local gme1 "(df_eduhsless)"
local gme2 "(df_edu12)"
local gme3 "(df_edu1315)"
local gme4 "(df_educollegeplus)"

forvalues i=1/6 {
tabstat eduhsless edu12 edu1315 educollegeplus [aw=wgt]  `condition`i'' & female==1 , stats(mean) save
matrix A`i'=r(StatTotal)'
tabstat eduhsless edu12 edu1315 educollegeplus [aw=wgt]  `condition`i'' & female==1 & ft==1 & anychild6==1, stats(mean) save
matrix C`i'=r(StatTotal)'
}
matrix B= A1, A2, A3, A4, A5, A6
matrix list B
matrix D= C1, C2, C3, C4, C5, C6
matrix list D


forvalues i=1/6 {
foreach participation in ft {

scalar sca1 = B[1,`i']
scalar sca2 = B[2,`i']
scalar sca3 = B[3,`i']
scalar sca4 = B[4,`i']

reg w_`participation' eduhsless edu12 edu1315 educollegeplus df_e* dfdz_e* [pw=wgt] `condition`i'' & `participation'==1, noc
lincom sca1*`ge1'+sca2*`ge2'+sca3*`ge3'+sca4*`ge4'
matrix L`i'=(r(estimate)\r(se))'

scalar sca1 = B[1,`i']
scalar sca2 = B[2,`i']
scalar sca3 = B[3,`i']
scalar sca4 = B[4,`i']

reg w_`participation' eduhsless edu12 edu1315 educollegeplus df_e* [pw=wgt] `condition`i'' & `participation'==1, noc
lincom sca1*`gme1'+sca2*`gme2'+sca3*`gme3'+sca4*`gme4'
matrix M`i'=(r(estimate)\r(se))'

probit `participation' eduhsless edu12 edu1315 educollegeplus `iv' [pw=wgt] `condition`i'' & female==1
predict p`participation'`i' if e(sample), xb
gen m`participation'`i'=normalden(p`participation'`i')/normal(p`participation'`i') `condition`i'' & female==1
replace m`participation'`i'=0 `condition`i'' & female==0
reg w_`participation' eduhsless edu12 edu1315 educollegeplus df_e*  m`participation'`i' [pw=wgt] `condition`i'' & `participation'==1, noc
lincom sca1*`gme1'+sca2*`gme2'+sca3*`gme3'+sca4*`gme4'
matrix P`i'=(r(estimate)\r(se))'
}
}

matrix G=(L1,M1,P1\L2,M2,P2\L3,M3,P3\L4,M4,P4\L5,M5,P5\L6,M6,P6)
matrix list G

preserve
svmat G
keep G*
drop if G1==.
gen x=_n
label define lyear 1 "1976-1980" 2 "1981-1985" 3  "1986-1990" 4 "1991-1995" 5 "1996-2000" 6 "2001-2005" 
label values x lyear

list G1 G3 G5

set obs 7
replace x=6.1 if _n==7
graph twoway (connected  G1 x, lpattern(solid) msymbol(smtriangle)) ///
	      (connected  G3 x, lpattern(shortdash) msymbol(smcircle)) ///
             (connected  G5 x, lpattern(longdash_dot) msymbol(smx)), ///
             legend(rows(1) ring(3) region(color(none) margin(zero)) ///
                        /*size(small)*/ symysize(*.5) symxsize(*1.2)) ///
             legend(label(1 "Local") label(2 "Observed") label(3 "Parametric")) ///
             graphregion(color(white) icolor(white) fcolor(white)ifcolor(white) ) ///
             ytitle("") xtitle("") xlabel(1(1)6, valuelabel labsize(small)) ylabel(-.5(.1)-.2, labsize(small)) 
graph save ${replication}figure2.gph, asis replace
graph export ${replication}figure2.eps, replace

restore

end // program figure2


***********************
/*Running the program*/
***********************
table2
table3
table4
table5
figure1
figure2

